@@ -1,5 +1,8 @@
 from firestore_collections.collection import Collection
-from firestore_collections.enums import OrderByDirection
+from firestore_collections.enums import (
+    FirestoreTimestamp,
+    OrderByDirection,
+)
 from firestore_collections.schema import (
     Schema,
     SchemaWithOwner,
@@ -8,6 +11,7 @@ from firestore_collections.schema import (
 
 __all__ = [
     'Collection',
+    'FirestoreTimestamp',
     'OrderByDirection',
     'Schema',
     'SchemaWithOwner',
